@@ -44,6 +44,7 @@ from pyramid.authorization import Authenticated
 from pyramid.authorization import Everyone
 
 from pyramid_helpers.utils import get_settings
+from pyramid_helpers.utils import request_cache
 from pyramid_helpers.utils import resolve_dotted
 
 
@@ -194,6 +195,7 @@ class MultiSecurityPolicy:
 
         return []
 
+    @request_cache()
     def identity(self, request):
         """ Get the identity of the current user """
 
