@@ -219,7 +219,7 @@ class Pager(list):
 
         self.page_count = ((self.item_count - 1) // self.limit) + 1
         self.first_page = 1
-        self.last_page = self.page_count
+        self.last_page = self.page_count or 1
 
         if self.page < self.first_page:
             self.__page = self.first_page
@@ -267,9 +267,10 @@ def paginate(name, partial_template=None, **pager_kwargs):
     """ Pagination decorator """
 
     def wrapper(func, *args, **kwargs):
+        """ Decorator Wrapper function """
 
         # Get request object from args
-        # First arg is «self» when func is method
+        # First arg is «self» when func is a method
         request = None
         for arg in args:
             if isinstance(arg, Request):
